.. module:: jnrbase.i18n
   :synopsis: Configure internationalisation support

i18n
====

Functions
---------

.. autofunction:: setup

.. _i18n-examples:

Examples
--------

.. testsetup::

    from jnrbase.i18n import setup

.. doctest::
   :options: +SKIP

    >>> _, N_ = setup(jnrbase)
    >>> _('I don’t speak Arabic')
    'Ana ma ba’aref ahkee Arabee'
